#!/usr/bin/bash

#yellow start 
	C14="\e[1;33m"
#blue start 
	C01="\e[0;34m"
#color end
	CE="\e[0m"
#light green start
	C10="\e[1;32m"
YNNO="("$C14"y"$CE"/"$C14"N"$CE")("$C14"Enter"$CE"=no)"

HOMEDIR="/home/pi"
ROOTDIR="/opt/retropie"
CONFIGDIR="$ROOTDIR/configs"
RETROPIE="$HOMEDIR/RetroPie"
ROMS="$RETROPIE/roms"

function presskey() {
  echo ""
  echo -e $C10"Press a key to continue..."$CE
  read -n 1
}

check_internet(){
 ping -c 1 www.google.com 2>&1 >/dev/null
 if [ $? != 0 ]; then
  read -p "Internet Connection Not Available. Press "$C14"ENTER"$CE" to continue..."
  echo 1
 fi
}

check_command(){
  if ! command -v "$1" 2>&1 >/dev/null
  then
    echo "$1 could not be found."
    return 1
  fi
}

function about() {
  clear
  echo -e "$C14[] Backup utility for Retropie!$CE"
  echo ""
  echo "A script to save hiscores, save states, config file etc."
  echo "You need a keyboard, internet connection and FZF utility."
  echo ""
  echo -e $C14"Made by XQTR // https://cp737.net"$CE
  presskey
}

prompt_confirm_no() {
  while true; do
    echo -e -n "${1:-Confirm?} ${YNNO}: "
    read -e -r -n 1 REPLY
    case $REPLY in
      [yY]) echo ; return 0 ;;
      [nN]) echo; echo "Aborted..."; sleep 1; return 1 ;;
      $'\0A') echo; echo "Aborted..."; sleep 1; return 1 ;;
      *) printf " \033[31m %s \n\033[0m" "invalid input"
    esac 
  done  
}

function delete_file() {
  clear
  cd "$ROMS"
  file="$(find . -name "*.xz" | fzf --header "Select file")"
  if [ -f "$ROMS/$file" ]; then
    echo "Are you sure to delete file:"
    echo " "
    echo "$ROMS/$file"
    echo " "    
    prompt_confirm_no || return -1
    echo "File $ROMS/$file, deleted!"
    rm "$ROMS/$file"
    presskey
  fi
}

function backup_all() {
  clear
  cd "$ROMS"
  FN="retropie_saves_$(date +"%Y%m%d").tar.xz"
  echo " "
  echo -e "Creating backup file. Please wait..."
  echo " "
  find . \
-name "*.srm" \
-o -name "*.state*" \
-o -name "*.cfg" \
-o -name "*.fs" \
-o -name "*.hi" \
-o -name "*.nv" \
-o -name "*.xml" \
-o -name "*.rtc" \
-o -name "*.sav" | tar -PcJf "$ROMS/$FN" -T -
  echo " "
  echo -e $C14"Backup file saved at:"$CE
  echo -e $C14"> $ROMS/$FN"$CE
  presskey  
  
}

function mnu_main() {
  option=""
  while [ -z "$option"  ]
  do 
    option=$(echo "1. Backup
2. Delete backup files
A. About
E. Edit script
X. Exit" | fzf --reverse --header "Main Menu")

    if [ ! -z "$option" ]
    then
      ch="$option"
      case $ch in
      # /home is selected
        1.*) backup_all;;
        2.*) delete_file;;
        A.*) about;;
        E.*) nano "$RETROPIE/retropiemenu/backup.sh";;
        X.*) break;;
        esac
    fi
  option=""
  done
}

clear

# Check if FZF exists, must be for root user
check_command fzf
if [ $? != 0 ]; then
  echo "FZF command doesn't exit. Install it to use this script."
  exit 1 
fi

check_internet
mnu_main
clear
